@@ -24,7 +24,12 @@ class TimeoutInterrupt(_MrqInterrupt):
 
 
 class AbortInterrupt(_MrqInterrupt):
-    pass
+    path = None
+
+    def _get_exception_name(self):
+        return "%s" % (
+            self.path
+        )
 
 
 class RetryInterrupt(_MrqInterrupt):
@@ -40,7 +45,12 @@ class RetryInterrupt(_MrqInterrupt):
 
 
 class MaxRetriesInterrupt(_MrqInterrupt):
-    pass
+    path = None
+
+    def _get_exception_name(self):
+        return "%s" % (
+            self.path
+        )
 
 
 class StopRequested(GreenletExit):
@@ -54,4 +64,9 @@ class JobInterrupt(GreenletExit):
 
 
 class MaxConcurrencyInterrupt(_MrqInterrupt):
-    pass
+    path = None
+
+    def _get_exception_name(self):
+        return "%s" % (
+            self.path
+        )
